@@ -1,4 +1,5 @@
 import warnings
+from base64 import standard_b64decode
 from collections import OrderedDict
 from datetime import datetime, date, time, timedelta
 from decimal import Decimal
@@ -87,7 +88,7 @@ def json_date_time_hook(dct):
 
 def json_complex_hook(dct):
 	"""
-	Return an encoded complex number to it's python representation.
+	Return an encoded complex number to Python complex type.
 
 	:param dct: (dict) json encoded complex number (__complex__)
 	:return: python complex number
@@ -101,6 +102,22 @@ def json_complex_hook(dct):
 	return parts[0] + parts[1] * 1j
 
 
+def json_bytes_hook(dct):
+	"""
+	Return encoded bytes, either base64 or utf8, back to Python bytes.
+
+	:param dct: any object, if it is a dict containing encoded bytes, they will be converted
+	:return: python complex number
+	"""
+	if not isinstance(dct, dict):
+		return dct
+	if '__bytes_b64__' in dct:
+		return standard_b64decode(dct['__bytes_b64__'])
+	if '__bytes_utf8__' in dct:
+		return dct['__bytes_utf8__'].encode('utf-8')
+	return dct
+
+
 def numeric_types_hook(dct):
 	if not isinstance(dct, dict):
 		return dct
@@ -300,6 +317,8 @@ def _lists_of_numbers_to_ndarray(data, order, shape, dtype):
 	"""
 	from numpy import asarray
 	arr = asarray(data, dtype=dtype, order=order)
+	if 0 in shape:
+		return arr.reshape(shape)
 	if shape != arr.shape:
 		warnings.warn('size mismatch decoding numpy array: expected {}, got {}'.format(shape, arr.shape))
 	return arr
