@@ -10,13 +10,13 @@ from .comment import strip_comments  # keep 'unused' imports
 from .encoders import TricksEncoder, json_date_time_encode, \
 	class_instance_encode, json_complex_encode, json_set_encode, numeric_types_encode, numpy_encode, \
 	nonumpy_encode, nopandas_encode, pandas_encode, noenum_instance_encode, \
-	enum_instance_encode, pathlib_encode # keep 'unused' imports
+	enum_instance_encode, pathlib_encode, bytes_encode  # keep 'unused' imports
 from .decoders import TricksPairHook, \
 	json_date_time_hook, ClassInstanceHook, \
 	json_complex_hook, json_set_hook, numeric_types_hook, json_numpy_obj_hook, \
 	json_nonumpy_obj_hook, \
 	nopandas_hook, pandas_hook, EnumInstanceHook, \
-	noenum_hook, pathlib_hook, nopathlib_hook  # keep 'unused' imports
+	noenum_hook, pathlib_hook, nopathlib_hook, json_bytes_hook  # keep 'unused' imports
 
 
 ENCODING = 'UTF-8'
@@ -25,9 +25,9 @@ ENCODING = 'UTF-8'
 _cih_instance = ClassInstanceHook()
 _eih_instance = EnumInstanceHook()
 DEFAULT_ENCODERS = [json_date_time_encode, json_complex_encode, json_set_encode,
-					numeric_types_encode, class_instance_encode, ]
+					numeric_types_encode, class_instance_encode, bytes_encode,]
 DEFAULT_HOOKS = [json_date_time_hook, json_complex_hook, json_set_hook,
-				numeric_types_hook, _cih_instance, ]
+				numeric_types_hook, _cih_instance, json_bytes_hook,]
 
 
 #TODO @mark: add properties to all built-in encoders (for speed - but it should keep working without)
@@ -103,9 +103,10 @@ def dumps(obj, sort_keys=None, cls=None, obj_encoders=DEFAULT_ENCODERS, extra_ob
 	dict_default(properties, 'allow_nan', allow_nan)
 	if cls is None:
 		cls = TricksEncoder
-	txt = cls(sort_keys=sort_keys, obj_encoders=encoders, allow_nan=allow_nan,
+	combined_encoder = cls(sort_keys=sort_keys, obj_encoders=encoders, allow_nan=allow_nan,
 		primitives=primitives, fallback_encoders=fallback_encoders,
-	  	properties=properties, **jsonkwargs).encode(obj)
+	  	properties=properties, **jsonkwargs)
+	txt = combined_encoder.encode(obj)
 	if not is_py3 and isinstance(txt, str):
 		txt = unicode(txt, ENCODING)
 	if not compression:
